AutoGen StudioBuild Multi-Agent Apps

#

Search
Settings1
Settings
Settings
Manage your settings and preferences

### UI Settings

Show LLM Events Display detailed LLM call logs in the message thread
Expand Messages by Default Automatically expand message threads when they load
Show Agent Flow by Default Display the agent flow diagram automatically
These settings are automatically saved and synced across browser sessions
Maintained by the AutoGen Team.